@@ -15,6 +15,8 @@ from pykwalify.core import Core
 from jinja2 import Environment, FileSystemLoader, Template
 from betterboto import client as betterboto_client
 import pkg_resources
+from terminaltables import AsciiTable
+from colorclass import Color
 
 VERSION = pkg_resources.require("aws-service-catalog-puppet")[0].version
 
@@ -504,7 +506,7 @@ def deploy_launches_for_region_and_product(
                 'SearchQuery': ['productId:{}'.format(product_id)]
             }
         )
-        already_provisioned_successfully = False
+        needs_to_be_provisioned = True
         for provisioned_product in response.get('ProvisionedProducts', []):
             logger.info("Found previous vend of product: {}".format(provisioned_product))
             if provisioned_product.get('Status') == 'ERROR':
@@ -525,10 +527,20 @@ def deploy_launches_for_region_and_product(
                         break
 
             elif provisioned_product.get('Status') == 'AVAILABLE':
-                logger.info('Already provisioned product')
-                already_provisioned_successfully = True
+                logger.info('Already provisioned product: {}'.format(provisioned_product.get('ProvisioningArtifactId')))
+                if provisioned_product.get('ProvisioningArtifactId') != provisioning_artifact_id:
+                    needs_to_be_provisioned = True
+                    r = service_catalog.list_provisioned_product_plans(
+                        ProvisionProductId=provisioned_product.get('Id')
+                    )
+                    for provisioned_product_plan in r.get('ProvisionedProductPlans', []):
+                        service_catalog.delete_provisioned_product_plan(
+                            PlanId=provisioned_product_plan.get('PlanId'),
+                        )
+                else:
+                    needs_to_be_provisioned = False
 
-        if not already_provisioned_successfully:
+        if needs_to_be_provisioned:
             logger.info('Creating plan, params: {}'.format(params))
             response = service_catalog.create_provisioned_product_plan(
                 PlanName=stack_name,
@@ -589,6 +601,7 @@ def deploy_launches_for_region_and_product(
                 logger.info("Product provisioned")
             else:
                 raise Exception("Execute was not successful: {}".format(execute_status))
+            service_catalog.delete_provisioned_product_plan(PlanId=plan_id)
 
 
 def deploy_launches(deployment_map, parameters, single_account, puppet_account_id):
@@ -754,9 +767,13 @@ def list_launches(f):
     ALL_REGIONS = get_regions()
     manifest = yaml.safe_load(f.read())
     account_ids = [a.get('account_id') for a in manifest.get('accounts')]
+    table_data = [
+        ['Account', 'Region', 'Portfolio', 'Launch','Product', 'Version', 'Status']
+    ]
     for account_id in account_ids:
         for region_name in ALL_REGIONS:
             role = "arn:aws:iam::{}:role/{}".format(account_id, 'servicecatalog-puppet/PuppetRole')
+            logger.info("Looking at region: {} in account: {}".format(region_name, account_id))
             with betterboto_client.CrossAccountClientContextManager(
                     'servicecatalog', role, 'sc-{}-{}'.format(account_id, region_name), region_name=region_name
             ) as spoke_service_catalog:
@@ -770,6 +787,21 @@ def list_launches(f):
                         response = spoke_service_catalog.search_provisioned_products(
                             Filters={'SearchQuery': ["productId:{}".format(product_id)]})
                         for provisioned_product in response.get('ProvisionedProducts', []):
+                            launch_name = provisioned_product.get('Name')
+                            status = provisioned_product.get('Status')
+                            if status == "AVAILABLE":
+                                status = Color("{green}"+status+"{/green}")
+                            else:
+                                status = Color("{red}"+status+"{/red}")
+                            table_data.append([
+                                account_id,
+                                region_name,
+                                portfolio.get('DisplayName'),
+                                launch_name,
+                                manifest.get('launches').get(launch_name).get('product'),
+                                manifest.get('launches').get(launch_name).get('version'),
+                                status,
+                            ])
                             output_path = os.path.sep.join([
                                 LAUNCHES,
                                 account_id,
@@ -784,6 +816,7 @@ def list_launches(f):
                                     provisioned_product,
                                     indent=4, default=str
                                 ))
+    click.echo(AsciiTable(table_data).table)
 
 
 def expand_path(account, client):
